#!/usr/bin/env python3

import sys
import collections
import lib_path
import lib
import argparser
import dphysldap

OPTS = collections.OrderedDict()
OPTS['access'] = 'accessRight'
OPTS['blocked'] = 'blocked'
OPTS['home'] = 'homeDirectory'
OPTS['shell'] = 'loginShell'
OPTS['report'] = ['reportEnabled', 'reportUid']
OPTS['mail'] = 'mail'
OPTS['telephone'] = 'telephoneNumber'

NOOPTS = collections.OrderedDict()
NOOPTS['no-member'] = 'memberUid'
NOOPTS['no-gid'] = 'gidNumber'
NOOPTS['no-owner'] = 'owner'


def main():
    description = 'Show groups or group members'
    arg = 'group'
    arg_help = 'The group name (cn), or wildcards (*, cn* , *cn*)'
    args = argparser.simple(description, arg=arg, arg_help=arg_help, opts=OPTS, noopts=NOOPTS)

    ldap = dphysldap.Ldap()

    group_attrs = ['cn', 'gidNumber', 'owner', 'memberUid']

    if args['report']:
        group_attrs.extend(OPTS['report'])

    groups = dphysldap.Groups(ldap, group_attrs)
    groups.search(args['group'])

    if not groups:
        sys.exit('No groups found.')

    if len(groups) != 1:
        #groups.sort('cn')
        groups.remove_attrs([v for k, v in NOOPTS.items() if args[k]])
        print(groups)

    else:
        group = groups[0]
        members = group['memberUid']

        print('Group {} ({}):'.format(group['cn'], group['gidNumber']))
        print('Owner: {}'.format(group['owner']))
        print('Report: {}'.format(group['reportEnabled']))
        print('Reported to: {}'.format(group['reportUid']))
        print('Members:')

        del OPTS['report']

        attrs = ['uid', 'uidNumber', 'gecos']
        attrs.extend([v for k, v in OPTS.items() if args[k]])

        users = dphysldap.Users(ldap, attrs)
        users.search(';'.join(members))
        #users.sort('uid')
        print(users)


if __name__ == "__main__":
    main()
